-- Copyright 2011 Stephan Hennig
--
--  This program is free software: you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation, either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program.  If not, see <http://www.gnu.org/licenses/>.

local handler_prototype = require('modules.GoogleBooks-2012-07-01.handler_prototype')

local handler = handler_prototype:new{
   --- Determine corpus file path.
   -- @field path
   -- @type string
   -- @example path = '~/gbc',
   path = arg[1],
   --
   --- Determine a selection of corpus files to process.
   -- Default is to process all files in the corpus.
   -- @field patterns
   -- @type string or table of strings
   -- @example patterns = { '5', '6' },
   --
   --- Determine particular Google Books corpus.
   -- Google Books corpora are available in different languages and
   -- collected from different sources.  Corpora can be identified by a
   -- tag, which is part of the corpus file names.
   -- @field tag
   -- @type string
   -- @example tag = 'ger-all',
   tag = 'ger-all',
   --
   --- Determine record filter.
   -- This call-back can be used to filter records (lines) read from the
   -- corpus by user-defined criteria.  If a filter function is given,
   -- records are ignored if the function returns a false value.  By
   -- default, the field is set to the value `nil`, i.e., no record
   -- filter is active and all records are considered valid.
   -- @field record_filter
   -- @type function or `nil`
   -- @arguments ngram, year, match count, page count, volume count
   -- @example record_filter = function(n,y,m,p,v) if y < 1800 then return true end end,
   --
   --- Determine ngram filter.
   -- This call-back can be used to filter aggregated ngrams (words)
   -- read from the corpus by user-defined criteria.  If a filter
   -- function is given, ngrams are ignored if the function returns a
   -- false value.  By default, the field is set to the value `nil`,
   -- i.e., no ngram filter is active and all ngrams are considered
   -- valid.
   -- @field ngram_filter
   -- @type function or `nil`
   -- @arguments ngram, cummulated match count, cummulated page count, cummulated volume count
   -- @example ngram_filter = function(n,m,p,v) if v < 50 then return true end end,
   --
   --- Determine output format.
   -- After reading in a Google Books corpus, a list of ngrams (the
   -- words) can be output to stdout.  This field determines the
   -- output format and can be one of:
   -- nil   No output.
   -- 'n'   Output a plain list of ngrams.
   -- 'nf'  Output a list 'ngram frequency'.
   -- 'nc'  Output a list 'ngram frequencyclass'.
   -- Default output format specification is 'n'.
   -- @field output_format
   -- @type string
   -- @example output_format = 'nf',
   output_format = 'nf',
   --
   --- Determine reference ngram.
   -- For frequency class calculation.
   -- @field reference_ngram
   -- @type string
   -- @example reference_ngram = 'the',
   reference_ngram = 'der',
   --
   --- Determine fall-back reference frequency.
   -- For frequency class calculation, in case reference ngram cannot be
   -- found in the corpus files read.
   -- @field reference_frequency
   -- @type number
   -- @example reference_frequency = 1000000,
}

handler:read_corpus()
handler:output_corpus()
